##  Prerequisites
  * You have accepted the AI terms.
  * You have purchased AI units and they are assigned to your tenant.
To verify eligibility, go to Administration > Optional Features and Early Access and check the AI Features section.
